@@ -240,7 +240,7 @@ extern "C"
 	WINPR_API BOOL ArrayList_Contains(wArrayList* arrayList, const void* obj);
 
 #if defined(WITH_WINPR_DEPRECATED)
-	WINPR_API WINPR_DEPRECATED(int ArrayList_Add(wArrayList* arrayList, const void* obj));
+	WINPR_DEPRECATED(WINPR_API int ArrayList_Add(wArrayList* arrayList, const void* obj));
 #endif
 
 	WINPR_API BOOL ArrayList_Append(wArrayList* arrayList, const void* obj);
@@ -306,7 +306,7 @@ extern "C"
 	 *  @param value The value to store for the \b key. May be \b NULL. if set cloned with \b
 	 * fnObjectNew
 	 *
-	 *  @return \b TRUE for successfull addition, \b FALSE for failure
+	 *  @return \b TRUE for successful addition, \b FALSE for failure
 	 */
 	WINPR_API BOOL ListDictionary_Add(wListDictionary* listDictionary, const void* key,
 	                                  const void* value);
@@ -608,7 +608,7 @@ extern "C"
 	 */
 	WINPR_API void CountdownEvent_Free(wCountdownEvent* countdown);
 
-	/** @brief Allocte a CountdownEvent with \b initialCount
+	/** @brief Allocate a CountdownEvent with \b initialCount
 	 *
 	 *  @param initialCount The initial value of the event
 	 *
@@ -628,7 +628,7 @@ extern "C"
 	WINPR_API size_t HashTable_Count(wHashTable* table);
 
 #if defined(WITH_WINPR_DEPRECATED)
-	WINPR_API WINPR_DEPRECATED(int HashTable_Add(wHashTable* table, const void* key,
+	WINPR_DEPRECATED(WINPR_API int HashTable_Add(wHashTable* table, const void* key,
 	                                             const void* value));
 #endif
 
@@ -821,20 +821,20 @@ extern "C"
 	typedef void (*p##name##EventHandler)(void* context, const name##EventArgs* e)
 
 #define DEFINE_EVENT_RAISE(name)                                                                \
-	static INLINE int PubSub_On##name(wPubSub* pubSub, void* context, const name##EventArgs* e) \
+	static inline int PubSub_On##name(wPubSub* pubSub, void* context, const name##EventArgs* e) \
 	{                                                                                           \
 		WINPR_ASSERT(e);                                                                        \
 		return PubSub_OnEvent(pubSub, #name, context, &e->e);                                   \
 	}
 
 #define DEFINE_EVENT_SUBSCRIBE(name)                                                              \
-	static INLINE int PubSub_Subscribe##name(wPubSub* pubSub, p##name##EventHandler EventHandler) \
+	static inline int PubSub_Subscribe##name(wPubSub* pubSub, p##name##EventHandler EventHandler) \
 	{                                                                                             \
 		return PubSub_Subscribe(pubSub, #name, EventHandler);                                     \
 	}
 
 #define DEFINE_EVENT_UNSUBSCRIBE(name)                                             \
-	static INLINE int PubSub_Unsubscribe##name(wPubSub* pubSub,                    \
+	static inline int PubSub_Unsubscribe##name(wPubSub* pubSub,                    \
 	                                           p##name##EventHandler EventHandler) \
 	{                                                                              \
 		return PubSub_Unsubscribe(pubSub, #name, EventHandler);                    \
